@@ -22,7 +22,8 @@ Output: feature_mx_<date>.csv file that contains all features in the <output_dir
 import sys
 import time
 import os
-from utils.extract_participant_id import extract_participant_id
+from microt_compliance_matrix import utils
+from microt_compliance_matrix import feature_engineering_ema
 
 
 def compute_features_phone(intermediate_participant_path, output_dir_path, date_in_study, decryption_password):
@@ -30,7 +31,7 @@ def compute_features_phone(intermediate_participant_path, output_dir_path, date_
     print_stats = False
 
     # Extract participant id from participant folder path
-    participant_id = extract_participant_id(intermediate_participant_path)
+    participant_id = utils.extract_participant_id.extract_participant_id(intermediate_participant_path)
 
     # Create output folder
     output_participant_path = os.path.join(output_dir_path, participant_id)
